@@ -384,7 +384,7 @@ void KimpanelInputPanelGraphics::setReverse(bool reverse, bool force)
             m_lowerLayout->addItem(m_lookupTableLayout);
             m_lowerLayout->setAlignment(m_lookupTableLayout, Qt::AlignLeft);
             m_lowerLayout->addItem(m_pageButtonLayout);
-            m_lowerLayout->setAlignment(m_pageButtonLayout, Qt::AlignVCenter | Qt::AlignRight);
+            m_lowerLayout->setAlignment(m_pageButtonLayout, Qt::AlignVCenter | Qt::AlignLeft);
         }
 
         if (lookuptableVisible)
